pygeodesy.epsg.Epsg

Package pygeodesy :: Module epsg :: Class Epsg |
[frames] | no frames]

# Class Epsg

              object --+
                       |
                     int --+
                           |
          object --+       |
                   |       |
        named._Named --+   |
                       |   |
    unitsBase._NamedUnit --+
                           |
               unitsBase.Int --+
                               |
                              Epsg

EPSG class, a named `int`.

Instance Methods
__repr__(self) Return a representation of this named `int`. |
__str__(self) Return this `Int` as standard `str`. |
utmupsStr(self, B=False) Get the UTM/UPS zone, band and hemisphere/-pole (`str`). |
Inherited from `unitsBase.Int`: `toRepr`, `toStr` Inherited from `int`: `__abs__`, `__add__`, `__and__`, `__cmp__`, `__coerce__`, `__div__`, `__divmod__`, `__float__`, `__floordiv__`, `__format__`, `__getattribute__`, `__getnewargs__`, `__hash__`, `__hex__`, `__index__`, `__int__`, `__invert__`, `__long__`, `__lshift__`, `__mod__`, `__mul__`, `__neg__`, `__nonzero__`, `__oct__`, `__or__`, `__pos__`, `__pow__`, `__radd__`, `__rand__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rlshift__`, `__rmod__`, `__rmul__`, `__ror__`, `__rpow__`, `__rrshift__`, `__rshift__`, `__rsub__`, `__rtruediv__`, `__rxor__`, `__sub__`, `__truediv__`, `__trunc__`, `__xor__`, `bit_length`, `conjugate` Inherited from `named._Named`: `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, eisu, **name) New Epsg (European Petroleum Survey Group) code from a UTM/USP coordinate or other EPSG code. |

Properties
| band Get the latitudinal UTM or polar UPS Band (`'A'|'B'|'C'|'D'|..|'W'|'X'|'Y'|'Z'` or `""`).
| hemisphere Get the UTM/UPS hemisphere/-pole (`'N'|'S'`).
| utmups Get the UTM/UPS original (Utm, Ups).
| zone Get the (longitudinal) UTM/UPS zone (`int`, `1..60` for UTM, `0` for UPS).
Inherited from `int`: `denominator`, `imag`, `numerator`, `real` Inherited from `unitsBase._NamedUnit`: `std_repr`, `units` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (cls, eisu, **name) Static Method |
New Epsg (European Petroleum Survey Group) code from a UTM/USP coordinate or other EPSG code. Arguments: `eisu` - Other code (Epsg, `int`, `str`, Utm or Ups). `name` - Optional `name=NN` (`str`). Returns: a new object with type S, a subtype of T New Epsg. Raises: `TypeError` - Invalid `eisu`. `EPSGError` - Invalid `eisu`. Overrides: object.__new__

### __repr__ (self) (Representation operator) |
Return a representation of this named `int`. Overrides: object.__repr__ (inherited documentation)

### __str__ (self) (Informal representation operator) |
Return this `Int` as standard `str`. Overrides: object.__str__ (inherited documentation)

Property Details

### band Get the latitudinal UTM or polar UPS Band (`'A'|'B'|'C'|'D'|..|'W'|'X'|'Y'|'Z'` or `""`). Get method: band(self) - Get the latitudinal UTM or polar UPS Band (`'A'|'B'|'C'|'D'|..|'W'|'X'|'Y'|'Z'` or `""`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### hemisphere Get the UTM/UPS hemisphere/-pole (`'N'|'S'`). Get method: hemisphere(self) - Get the UTM/UPS hemisphere/-pole (`'N'|'S'`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### utmups Get the UTM/UPS original (Utm, Ups). Get method: utmups(self) - Get the UTM/UPS original (Utm, Ups). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### zone Get the (longitudinal) UTM/UPS zone (`int`, `1..60` for UTM, `0` for UPS). Get method: zone(self) - Get the (longitudinal) UTM/UPS zone (`int`, `1..60` for UTM, `0` for UPS). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.